"""CMIS (REST aka AtomPub bind) interface to the document repository."""
from . import atompub  # noqa
